
from setuptools import setup, find_packages

setup(
    name='ctganenn',
    version='1.0.7',
    packages=find_packages(),
    install_requires=[
        'scikit-learn==1.6.1',
        'sdv==1.18.0',
        'pandas==2.0.3',
        # Add any dependencies your package needs
    ],
    author='Mahayasa Adiputra',
    author_email='mahayasa.a@kkumail.com',
    description='CTGAN-ENN : Tabular GAN-based Hybrid sampling method',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='',
    license='',
)


from imblearn.under_sampling import EditedNearestNeighbours
import pandas as pd
from sdv.metadata import SingleTableMetadata
from sdv.single_table import CTGANSynthesizer


def CTGANENN(minClass,majClass,genData,targetLabel):

    metadata = SingleTableMetadata()
    metadata.detect_from_dataframe(minClass)
    metadata.validate()

    synthesizer = CTGANSynthesizer(metadata)
    synthesizer.fit(minClass)
    synthetic_data = synthesizer.sample(num_rows=genData)

    #concat original data and gan data
    data_concat = pd.concat([minClass, synthetic_data])
    # combine data churn and not churn
    data=pd.concat([majClass, data_concat])
    enn = EditedNearestNeighbours(n_neighbors=3)
    X=data.drop([targetLabel],axis=1)
    y=data[targetLabel]
    X, y = enn.fit_resample(X, y)

    return X,y
